#!/bin/sh
#
# =======================
#  Creatures 3 Installer
# =======================
#
# Francis Irving <francis.irving@creaturelabs.com>
# Gary Briggs <gjb105@cs.york.ac.uk>
# Christian Zander <phoenix@minion.de>
#

# ---------------------------------------------------------------
# Default settings.
# ---------------------------------------------------------------

DEFAULT_INSTALL_DIR=/usr/local/games/creatures3
DEFAULT_SETUP_CDROM=/cdrom
DEFAULT_DS_INST_DIR=dockingstation
DEFAULT_SYMLINK_DIR=/usr/local/bin

#DEFAULT_INSTALL_DIR=/opt/games/Beta/Creatures3
#DEFAULT_SETUP_CDROM=/cdrom
#DEFAULT_DS_INST_DIR=CreaturesDS
#DEFAULT_SYMLINK_DIR=/opt/games/bin

# ---------------------------------------------------------------
# Support functions.
# ---------------------------------------------------------------

function error
{
  echo
  echo "Error: $1"
  echo

  exit 1
}

function to_lower_case
{
  for i in "$@"
  do
    if [ -d "$i" ]; then
      cd "$i"
      for j in *
      do
        to_lower_case "$j"
      done
      cd ..
    else
      new=`echo "$i" | tr "[:upper:]" "[:lower:]"`
      if [ "$new" != "$i" ]; then
        mv "$i" "$new"
      fi
    fi
  done
}

# ---------------------------------------------------------------
# This is where the fun begins.
# ---------------------------------------------------------------

clear

echo "=========================="
echo " Creatures 3 Installation "
echo "=========================="
echo
echo "This script will install Creatures 3 on your computer."
echo "You need to have Creatures Docking Station installed."
echo

echo -n "Do you wish to continue? [Y/n] "
read reply

if [ "$reply" = "n" ]; then
  echo
  echo "Installation aborted."
  echo

  exit 0
fi

SETUP_DIR=`pwd`

if [ ! $SETUP_CDROM ]; then
  echo -n "Creatures 3 CD mount-point? [$DEFAULT_SETUP_CDROM] "
  read SETUP_CDROM

  if [ ! $SETUP_CDROM ]; then
    SETUP_CDROM="$DEFAULT_SETUP_CDROM"
  fi
fi

if [ ! -d "$SETUP_CDROM" ]; then
  error "$SETUP_CDROM is not a valid mount-point."
fi

if ! (mount | grep "$SETUP_CDROM" > /dev/null 2>&1); then
 if ! (mount "$SETUP_CDROM"); then
  error "Unable to mount the Creatures 3 CD on $SETUP_CDROM."
 fi
fi

if [ ! $INSTALL_DIR ]; then
 echo -n "Installation path? [$DEFAULT_INSTALL_DIR] "
 read INSTALL_DIR

 if [ ! $INSTALL_DIR ]; then
  INSTALL_DIR="$DEFAULT_INSTALL_DIR"
 fi
fi

if [ ! -d "$INSTALL_DIR" ]; then
 if ! (mkdir -p "$INSTALL_DIR" > /dev/null 2>&1); then
  error "Unable to create $INSTALL_DIR."
 fi
fi

if [ ! -w "$INSTALL_DIR" ]; then
 error "$INSTALL_DIR is not writable."
fi

if [ ! $DS_INSTALL_DIR ]; then
  echo -n "Creatures DS installation path? "
  echo -n "[`dirname $INSTALL_DIR`/$DEFAULT_DS_INST_DIR] "
  read DS_INSTALL_DIR

  if [ ! $DS_INSTALL_DIR ]; then
    DS_INSTALL_DIR=`dirname $INSTALL_DIR`/"$DEFAULT_DS_INST_DIR"
  fi
fi

if [ ! -d "$DS_INSTALL_DIR" ]; then
  error "$DS_INSTALL_DIR does not exist."
fi

echo -n "Do you wish to install symlinks? [Y/n] "
read reply

if [ "$reply" != "n" ]; then
  echo -n "Install symlinks to? [$DEFAULT_SYMLINK_DIR] "
  read SYMLINK_DIR

  if [ ! $SYMLINK_DIR ]; then
    SYMLINK_DIR="$DEFAULT_SYMLINK_DIR"
  fi
fi

echo "Copying Creatures 3 files ..."

if ! (cp -dfR "$SETUP_CDROM"/Install/Install/* "$INSTALL_DIR"); then
 error "Unable to copy Creatures 3 files."
fi


echo ""
echo "Patching"
echo "you must have the creatures3_update2.exe in the current directory."
echo "Do you want to patch Creatures 3?"

read YN
if [ \(x$YN != xN\) -a \(x$YN != xn\) ]
then

 TEMP_DIRNAME="temp_c3_patch.$$"

 mkdir $TEMP_DIRNAME
 cd $TEMP_DIRNAME

 unzip -q ../creatures3_update2.exe

 for f in Bootstrap Catalogue Genetics Images
 do
  if [ ! -d $INSTALL_DIR/$f/ ]
  then
   mkdir -p $INSTALL_DIR/$f/
  fi
  cp -Rf "$f Directory"/* $INSTALL_DIR/$f/
 done

 if [ ! -d "$INSTALL_DIR/My Agents/" ]
 then
  mkdir -p "$INSTALL_DIR/My Agents/"
 fi
 cp -R "Resource Files Directory"/* "$INSTALL_DIR/My Agents/"


 for f in `cat "\`find . -name 'delete_list.txt'\`"`
 do
  rm `find $INSTALL_DIR -name $f` 2>/dev/null >/dev/null
 done

fi

# At which point, it should be patched...


cd ..
rm -rf $TEMP_DIRNAME








#
# Files copied from CD are write-protected. Make them writable and
# remove all Win32 related files.
#





chmod -R u+w "$INSTALL_DIR"
find "$INSTALL_DIR" -type f -exec chmod -x {} \;

rm "$INSTALL_DIR"/*.[Dd][Ll][Ll]
rm "$INSTALL_DIR"/*.[Ee][Xx][Ee]
rm "$INSTALL_DIR"/*.[Ii][Cc][Oo]
rm "$INSTALL_DIR"/*.[Uu][Rr][Ll]

#
# Copy files from an existing Docking Station installation
#

if [ ! -d "$INSTALL_DIR"/Catalogue ]; then
  mkdir "$INSTALL_DIR"/Catalogue
fi

cp "$DS_INSTALL_DIR"/{lc2e,lc2elib.so,*.xpm}    "$INSTALL_DIR"
cp "$DS_INSTALL_DIR"/{lang*,libSDL*}            "$INSTALL_DIR"
cp "$DS_INSTALL_DIR"/Catalogue/{Brain*,CAOS*}   "$INSTALL_DIR"/Catalogue
cp "$DS_INSTALL_DIR"/Catalogue/Norn*  "$INSTALL_DIR"/Catalogue
cp "$DS_INSTALL_DIR"/Catalogue/{vocab*,voices*} "$INSTALL_DIR"/Catalogue

#this section added by joshua to make sure ds sees the c3 installation
cp "$SETUP_DIR"/Patch.catalogue "$INSTALL_DIR"/Catalogue

mkdir "$INSTALL_DIR"/Users

#
# Linux filesystems, unlike FAT and friends, are case sensitive.
#

for i in Bootstrap Images Sounds "Overlay Data" "Body Data" Backgrounds
do
  to_lower_case "$INSTALL_DIR/$i"
done

cd "$SETUP_DIR"
cp creatures* *.cfg.template "$INSTALL_DIR"

if [ $SYMLINK_DIR ]; then
  if [ -w "$SYMLINK_DIR" ]; then
    ln -fs "$INSTALL_DIR"/creatures3 "$SYMLINK_DIR"/creatures3
    ln -fs "$INSTALL_DIR"/creatures3 "$SYMLINK_DIR"/c3
  else
    echo "Warning: $SYMLINK_DIR is not writable."
  fi
fi

echo
echo "Creatures 3 Installation completed successfully."
echo

exit 0
